/*
 * @Author: donghao donghao@supervision.ltd
 * @Date: 2024-03-27 16:03:20
 * @LastEditors: donghao donghao@supervision.ltd
 * @LastEditTime: 2024-05-10 17:46:32
 * @FilePath: \general-ai-manage\src\components\Header\index.tsx
 * @Description: 内层layout菜单配置
 */
import { useBusinessInfo } from '@/hooks/useBusinessInfo';
import { history, useIntl } from '@umijs/max';
import { ReactComponent as BusinessLogoIcon } from '/public/home/business_logo.svg';

import type { MenuProps } from 'antd';

import React, { useEffect, useState } from 'react';
import { ReactComponent as BusinessBigLogo } from '/public/home/business_big_logo.svg';
// import menuFooter from '/public/menuFooter.svg';

import './index.less';

export type MenuBarProps = {
  menuData: any[];
  changeMenu: (arg1: MenuProps) => void;
};

const MenuBar: React.FC<MenuBarProps> = ({ menuData, changeMenu }) => {
  const intl = useIntl();
  const { getStoreBusinessInfo } = useBusinessInfo();

  const [selectedMenu, setSelectedMenu] = useState([]);

  // const [stateOpenKeys, setStateOpenKeys] = useState(['1', '2']);

  // 根据路径查找对应的菜单项
  const findMenuByPath = (menuData: any, pathname: any) => {
    for (const item of menuData) {
      if (item.path === pathname) {
        return item;
      }
      // 多级菜单使用递归调用
      // if (item.children) {
      //   const matchedChild: any = findMenuByPath(item.children, pathname);
      //   if (matchedChild) {
      //     return matchedChild;
      //   }
      // }
    }
    return null;
  };

  const menuClick: MenuProps['onClick'] = (menuItem) => {
    console.log('menuClick_menuItem:', menuItem);
    // Check if menuItem has route defined
    if (menuItem && menuItem.path) {
      history.push(menuItem.path);
    }
  };

  // const onOpenChange: MenuProps['onOpenChange'] = (openKeys) => {
  //   console.log(openKeys, 'openKeys');
  //   const currentOpenKey = openKeys.find((key) => stateOpenKeys.indexOf(key) === -1);
  //   console.log(currentOpenKey, 'currentOpenKey');
  //   // open
  //   if (currentOpenKey !== undefined) {
  //     const repeatIndex = openKeys
  //       .filter((key) => key !== currentOpenKey)
  //       .findIndex((key) => levelKeys[key] === levelKeys[currentOpenKey]);

  //     setStateOpenKeys(
  //       openKeys
  //         // remove repeat key
  //         .filter((_, index) => index !== repeatIndex)
  //         // remove current level all child
  //         .filter((key) => levelKeys[key] <= levelKeys[currentOpenKey]),
  //     );
  //     localStorage.setItem(
  //       'openKeys',
  //       JSON.stringify(
  //         openKeys
  //           // remove repeat key
  //           .filter((_, index) => index !== repeatIndex)
  //           // remove current level all child
  //           .filter((key) => levelKeys[key] <= levelKeys[currentOpenKey]),
  //       ),
  //     );
  //   } else {
  //     // close
  //     setStateOpenKeys(openKeys);
  //     localStorage.setItem('openKeys', JSON.stringify(openKeys));
  //   }
  // };

  // 当路由变化时更新当前选中菜单项
  useEffect(() => {
    const pathname = history.location.pathname;
    const matchedMenu = findMenuByPath(menuData, pathname);
    console.log('matchedMenu', matchedMenu);
    if (matchedMenu) {
      setSelectedMenu([matchedMenu.key]);
      changeMenu(matchedMenu);
    }
  }, [menuData, history.location.pathname]);

  return (
    <div className="flex flex-col items-center justify-between menubar_wrap">
      <div>
        <div
          className="flex items-center justify-center menu_top"
          onClick={() => {
            history.replace('/');
          }}
        >
          <BusinessBigLogo></BusinessBigLogo>
        </div>
        <div className="flex items-center justify-center mx-[12px] mt-[16px] mb-[12px] p-[4px] bg-[#154DDD1a] text-[#154DDD] rounded-[8px] text-[14px]">
          <BusinessLogoIcon></BusinessLogoIcon>
          <span className="pl-[8px]">{getStoreBusinessInfo()?.name}</span>
        </div>
      </div>

      {/* // TODO 菜单需要补充路由聚焦状态  */}
      <div className="w-full menu_center">
        <ul className="w-full single_menu_box">
          {menuData &&
            menuData?.map((menuItem) => (
              <li
                className={`text1 flex items-center w-full ${
                  selectedMenu.includes(menuItem.key) ? 'active' : ''
                }`}
                key={menuItem.key}
                icon={menuItem.icon}
                onClick={() => menuClick(menuItem)}
              >
                <i className={`pl-[24px] pr-[12px] iconfont ${menuItem.menuIcon}`}></i>
                <div>
                  {intl.formatMessage({ id: `menu.${menuItem.name}`, defaultMessage: '菜单' })}
                </div>
              </li>
            ))}
        </ul>
        {/* <Menu
          mode="inline"
          selectedKeys={selectedMenu}
          openKeys={stateOpenKeys}
          onOpenChange={onOpenChange}
        >
          {menuData &&
            menuData?.map((menuItem) => (
              <Menu.Item
                key={menuItem.key}
                icon={menuItem.icon}
                onClick={() => menuClick(menuItem)}
              >
                {intl.formatMessage({ id: `menu.${menuItem.name}`, defaultMessage: '菜单' })}
              </Menu.Item>
            ))}
        </Menu> */}
      </div>
    </div>
  );
};

export default MenuBar;
