import { formatTreeValByKey } from '@/utils/baseTree';
import { DeleteFilled, SearchOutlined } from '@ant-design/icons';
import { Button, Form, Input, Modal, Tree } from 'antd';
import _debounce from 'lodash/debounce';
import React, { useEffect, useState } from 'react';
import { BaseTreeProps } from '../typing';

import { ProForm, ProFormText } from '@ant-design/pro-components';
import './baseTree.less';
const { TreeNode } = Tree;

const BaseTree: React.FC<BaseTreeProps> = (props) => {
  /**state */
  // const { token } = theme.useToken();

  const { treeData, ...defaultProps } = props;
  console.log(treeData, 'treeData', defaultProps);
  const [currTreeData, setCurrTreeData] = useState([
    // { title: '节点1', key: '1' },
    // { title: '节点2', key: '2', children: [{ title: '子节点1', key: '3' }] },
  ]);

  const [visible, setVisible] = useState(false);
  const [editNodeKey, setEditNodeKey] = useState(null);
  const [form] = Form.useForm();
  const action_add_key = '';

  /**工具方法集 */
  // 柯里化-树的节点数值
  function formatTreeValByNodeKey(
    key: 'title' | 'key' | 'children',
    node: Record<string, any>,
  ): any {
    return formatTreeValByKey(key, node, props.fieldNames);
  }

  /**查询树节点 */
  // 定义一个防抖处理函数，500ms 后执行 handleChange 函数
  const debouncedHandleChange = _debounce((value) => {
    // TODO 查询所有匹配的节点
    console.log('debouncedHandleChange_value:', value);
  }, 500);
  // 搜索节点
  function handleSearch(val) {
    debouncedHandleChange(val);
  }

  const handleAddNode = () => {
    // setVisible(true);
    // form.resetFields();
  };

  // const getNodeByKey = (key) => {
  //   return currTreeData.find((node) => node.key === key);
  // };

  // const removeNodeByKey = (data, key) => {
  //   return data.filter((node) => {
  //     if (node.key === key) {
  //       return false;
  //     }
  //     if (node.children) {
  //       node.children = removeNodeByKey(node.children, key);
  //     }
  //     return true;
  //   });
  // };

  // const handleEditNode = (key) => {
  //   setEditNodeKey(key);
  //   setVisible(true);
  //   form.setFieldsValue({ nodeTitle: getNodeByKey(key).title });
  // };

  // const handleDeleteNode = (key) => {
  //   const newData = removeNodeByKey(currTreeData, key);
  //   setCurrTreeData(newData);
  // };

  // const handleAddChildNode = (key) => {
  //   setEditNodeKey(key);
  //   setVisible(true);
  //   form.resetFields();
  // };

  // 组装节点数据
  const handleModalOk = () => {
    form.validateFields().then((values) => {
      const { nodeTitle } = values;
      let newData;
      if (editNodeKey) {
        // 编辑节点标题
        newData = currTreeData.map((node) => {
          if (node.key === editNodeKey) {
            return { ...node, title: nodeTitle };
          }
          return node;
        });
      } else if (editNodeKey === null) {
        // 新增根节点
        newData = [...currTreeData, { title: nodeTitle, key: Date.now().toString() }];
      } else {
        // 新增子节点
        newData = currTreeData.map((node) => {
          if (node.key === editNodeKey) {
            return {
              ...node,
              children: [
                ...(node.children || []),
                { title: nodeTitle, key: Date.now().toString() },
              ],
            };
          }
          return node;
        });
      }
      console.log('handleModalOk_newData', newData);
      setCurrTreeData(newData);
      setVisible(false);
      setEditNodeKey('');
    });
  };

  const handleModalCancel = () => {
    setVisible(false);
    setEditNodeKey('');
  };

  // render 新增节点操作
  const renderAddAction = (node?: Record<string, any>) => {
    // console.log(node, 'renderAddAction_node');
    return props?.addRender ? (
      props?.addRender(node)
    ) : (
      <div onClick={handleAddNode}>
        <Button>新增节点</Button>
      </div>
    );
  };

  // 定义每个节点内容 递归操作
  const renderTreeNodes = (data) => {
    if (Array.isArray(data) && data.length) {
      return data.map((node, index) => {
        return (
          <TreeNode
            {...node}
            title={formatTreeValByNodeKey('title', node)}
            key={formatTreeValByNodeKey('key', node) + index}
            className={`tree_node_item tree_node_${node.level}`}
          >
            {formatTreeValByNodeKey('children', node) &&
              renderTreeNodes(formatTreeValByNodeKey('children', node))}

            <TreeNode key={formatTreeValByNodeKey('key', node) + action_add_key}></TreeNode>
          </TreeNode>
        );
      });
    }
    return <></>;
  };
  // 渲染每个节点内容
  const renderTreeItem = (node) => {
    return (
      <div className="flex w-full">
        <span className="w-[140px]">{node.title}</span>
        {!props?.hideInDelete ? (
          <span
            className="action_list"
            onClick={() => {
              props.handleDelete(node);
            }}
          >
            <DeleteFilled />
          </span>
        ) : (
          <></>
        )}
      </div>
    );
  };

  useEffect(() => {
    setCurrTreeData(props.treeData);
    console.log(props.treeData, 'props_treeData');
  }, [props.treeData]);

  return (
    <div className="base_tree_wrap">
      {!props?.hideInSearch ? (
        <ProForm className="tree_search_form" submitter={false}>
          <ProFormText
            className=" mb-[0px]"
            onChange={(e) => handleSearch(e.target.value)}
            key="name"
            name="name"
            label=""
            fieldProps={{
              style: {
                margin: 0,
              },
              prefix: <SearchOutlined style={{ color: 'rgba(0,0,0,.25)' }} />,
            }}
          />
        </ProForm>
      ) : (
        <></>
      )}
      <Tree
        defaultExpandAll
        onSelect={(selectedKeys, info) => {
          console.log('selected', selectedKeys);
          props.selectTree(selectedKeys, info);
        }}
        titleRender={(node) => {
          if (node.title) {
            return renderTreeItem(node);
          }
          return renderAddAction(node);
        }}
        {...defaultProps}
      >
        {renderTreeNodes(currTreeData)}
      </Tree>
      <div className="tree_node_1">{renderAddAction()}</div>
      {/* <div onClick={handleAddNode}>添加一级节点</div> */}

      {/* TODO 使用ProForm */}
      <Modal
        title={editNodeKey ? '编辑节点' : '新增节点'}
        open={visible}
        onOk={handleModalOk}
        onCancel={handleModalCancel}
      >
        <Form form={form}>
          <Form.Item
            name="nodeTitle"
            label="节点名称"
            rules={[{ required: true, message: '请输入节点名称' }]}
          >
            <Input />
          </Form.Item>
        </Form>
      </Modal>
    </div>
  );
};

export default BaseTree;
