/*
 * @Author: donghao donghao@supervision.ltd
 * @Date: 2024-04-22 15:23:36
 * @LastEditors: donghao donghao@supervision.ltd
 * @LastEditTime: 2024-05-07 13:26:50
 * @FilePath: \general-ai-platform-web\src\pages\Node\BusinessModel\index.tsx
 * @Description: 业务模型
 * @交互说明
 * 1、业务模型列表的分页展示
 * 2、新增、更新、删除（模型）功能
 * 3. 模型详情展示
 */
// const BusinessModel: React.FC = () => {
//   return <div className="businessModel_page">业务模型</div>;
// };

// export default BusinessModel;

import TableActionCard from '@/components/TableActionCard';
import IsDelete from '@/components/TableActionCard/isDelete';
import { getBusinessModelList } from '@/services/testApi/businessModel';
import { ExclamationCircleFilled } from '@ant-design/icons';
import type { ActionType, ProColumns } from '@ant-design/pro-components';
import { ProCard, ProTable } from '@ant-design/pro-components';
import { FormattedMessage } from '@umijs/max';
import { Button } from 'antd';
import { useRef, useState } from 'react';
import { proTablePaginationOptions } from '../../../../config/defaultTable';
import CreateForm from './components/createForm';

const BusinessModel: React.FC = () => {
  // const intl = useIntl();
  const actionRef = useRef<ActionType>();

  const [createModalOpen, setCreateModalOpen] = useState<boolean>(false);
  // const [categoryFkIdIds, setCategoryFkIdIds] = useState([]);
  //  动态设置每页数量
  const [currentPageSize, setCurrentPageSize] = useState<number>(10);
  // const [currentRow, setCurrentRow] = useState<Record<string, any>>({});

  /**
   * @en-US The pop-up window of the distribution update window
   * @zh-CN 分布更新窗口的弹窗
   * */
  // const [updateModalOpen, setUpdateModalOpen] = useState<boolean>(false);
  // const [showDetail, setShowDetail] = useState<boolean>(false);

  /**新增 编辑 删除 */
  // 新增
  const handleCreateModal = () => {
    if (createModalOpen) {
      setCreateModalOpen(false);
    } else {
      setCreateModalOpen(true);
    }
  };

  function reloadList() {
    actionRef.current?.reload();
  }

  // 业务模型列表信息
  const columns: ProColumns<Record<string, any>>[] = [
    {
      title: <FormattedMessage id="business_model.table.list.name" defaultMessage="名称" />,
      dataIndex: 'name',
      hideInSearch: true,
      key: 'fixedName',
      fixed: 'left',
      width: '40%',
    },

    {
      title: (
        <FormattedMessage id="business_model.table.list.createTime" defaultMessage="创建时间" />
      ),
      dataIndex: 'createTime',
      hideInSearch: true,
      valueType: 'dateTime',
    },

    {
      title: <FormattedMessage id="pages.searchTable.titleOption" defaultMessage="Operating" />,
      dataIndex: 'option',
      valueType: 'option',
      fixed: 'right',
      key: 'option',
      render: (_, record) => [
        <TableActionCard
          key="TableActionCardRef"
          renderActions={[
            {
              key: 'updateDetail',
              renderDom: (
                <Button
                  key="updateDetail"
                  type="link"
                  size="small"
                  onClick={() => {
                    // TODO 编辑在新增联调后实现
                    // setCurrentRow(record);
                    // history.push('/home/model-detail');
                    // doToDetail(record);
                    // setShowDetail(true);
                    // setUpdateModalOpen(true);
                  }}
                >
                  <FormattedMessage id="pages.searchTable.updateDetail" defaultMessage="查看" />
                </Button>
              ),
            },
            {
              key: 'destroy',
              renderDom: (
                <IsDelete
                  deleteApi={() => {
                    handleDestroy(record).then(() => {});
                  }}
                ></IsDelete>
              ),
            },
          ]}
        ></TableActionCard>,
      ],
    },
  ];
  return (
    <div className="businessModel_page gn_head_card">
      <ProCard
        className="gn_card pb-[16px]"
        title={
          <span className="head3">
            <FormattedMessage id="business_model.table.title" defaultMessage="标题" />
          </span>
        }
        extra={
          <Button
            type="primary"
            onClick={() => {
              setCreateModalOpen(true);
            }}
          >
            <FormattedMessage id="business_model.table.list.add.name" defaultMessage="新增" />
          </Button>
        }
      >
        <div
          className="pb-[12px]"
          style={{
            color: '#FAAD14',
          }}
        >
          <ExclamationCircleFilled />
          <span className="pl-[8px]">业务模型需关联设备节点请先至“设备节点”页创建需关联的节点</span>
        </div>
        <ProTable
          className="gn_pro_table"
          cardProps={{
            bodyStyle: { padding: 0 },
          }}
          // 标题栏
          search={false}
          options={{ fullScreen: false, setting: false, density: false, reload: false }}
          actionRef={actionRef}
          rowKey="id"
          onDataSourceChange={(data) => {
            console.log(data, 'onDataSourceChange_data');
            // let CategoryFkIdIds: any = data.map((v) => {
            //   return v.categoryFkId;
            // });
            // setCategoryFkIdIds(CategoryFkIdIds);
          }}
          pagination={{
            ...proTablePaginationOptions,
            pageSize: currentPageSize,
            onChange: (page, pageSize) => setCurrentPageSize(pageSize),
          }}
          columnsState={{
            persistenceKey: 'algorithm_model_list',
            persistenceType: 'localStorage',
          }}
          request={async (params = {}) => {
            const { current, ...rest } = params;
            const reqParams = {
              page: current,
              ...rest,
            };
            let resp = await getBusinessModelList({ ...reqParams });
            console.log(resp, 'getModelVersionList_resp');
            return {
              data: resp.data?.results,
              success: resp.success,
              total: resp.data.count,
              current: current,
              pageSize: currentPageSize,
            };
          }}
          columns={columns}
        />
      </ProCard>
      <CreateForm
        createModalOpen={createModalOpen}
        handleModal={handleCreateModal}
        reload={reloadList}
      />
    </div>
  );
};

export default BusinessModel;
