/*
 * @Author: donghao donghao@supervision.ltd
 * @Date: 2024-05-10 10:47:45
 * @LastEditors: donghao donghao@supervision.ltd
 * @LastEditTime: 2024-05-13 16:13:55
 * @FilePath: \general-ai-platform-web\src\pages\Business\BusinessState\deviceSate.tsx
 * @Description: 设备状态列表
 * @交互说明
 * 1、设备状态列表的查看、重启
 * 2、设备状态基本信息展示
 */

import { CommButton, TextButton } from '@/components/Button';
import IsConfirmAction from '@/components/TableActionCard/isConfirmAction';
import { deviceStateEnums } from '@/enums/device';
import { getDeviceStateList } from '@/services/testApi/businessState';
import { getDictDeviceType } from '@/services/testApi/dict';
import { isSuccessApi } from '@/utils/forApi';
import { ProCard, ProForm, ProFormSelect, ProList } from '@ant-design/pro-components';
import { FormattedMessage, useIntl } from '@umijs/max';
import { Tabs } from 'antd';
import { useEffect, useState } from 'react';
import { proTablePaginationOptions } from '../../../../config/defaultTable';
import DetailDeviceState from './components/detailDeviceState';
import DeviceStateCard from './components/deviceStateCard';
import './index.less';
import { ReactComponent as ResetIcon } from '/public/home/reset_icon.svg';
import { ReactComponent as SearchIcon } from '/public/home/search_icon.svg';

const DeviceSate: React.FC = () => {
  /**state */
  const intl = useIntl();
  // 列表
  const [serverList, setServerList] = useState<Record<string, any>[]>([]); // 列表数据
  const [currentRow, setCurrentRow] = useState<Record<string, any>>();
  const [currentPageSize, setCurrentPageSize] = useState<number>(8);
  const [currentPage, setCurrentPage] = useState<number>(1);
  const [total, setTotal] = useState<number>(1);

  // 详情展示
  const [detailOpen, setDetailOpen] = useState<boolean>(false);

  // 切换筛选
  const [form] = ProForm.useForm(); // form 对象
  const [querysData, setQuerysData] = useState<Record<string, any>>({}); // 列表查询参数
  const [tabKey, setTabKey] = useState<string>(deviceStateEnums[0].key);
  const [tabs, setTabs] = useState<DICTENUM.DICT_TAB_ITEM[]>([]);

  // 将数据组装成reactDom
  function toListDomByData(record) {
    let startList = [...record];
    let finalList = startList.map((item) => ({
      content: (
        <DeviceStateCard
          info={item}
          fetchDetail={() => {
            setCurrentRow(item);
            setDetailOpen(true);
          }}
          renderActions={[
            {
              key: 'detail',
              renderDom: (
                <span>
                  <TextButton
                    className="text-[12px]"
                    buttonLabel={
                      <FormattedMessage id="pages.searchTable.detail" defaultMessage="详情" />
                    }
                    buttonType="primary"
                  ></TextButton>
                </span>
              ),
            },
            {
              key: 'destroy',
              renderDom: (
                <span>
                  <IsConfirmAction
                    title={`${intl.formatMessage({
                      id: 'pages.searchTable.reOpen',
                      defaultMessage: '重启',
                    })}`}
                    buttonRender={
                      <TextButton
                        fontSize={12}
                        buttonLabel={
                          <FormattedMessage id="pages.searchTable.reOpen" defaultMessage="重启" />
                        }
                        buttonType="danger"
                      ></TextButton>
                    }
                    confirmAction={() => {
                      // TODO 调用重启接口
                    }}
                  />
                </span>
              ),
            },
          ]}
        ></DeviceStateCard>
      ),
    }));
    setServerList(finalList);
    console.log(finalList, 'toListDomByData_finalList');
  }

  // 企业列表数据api
  async function fetchData() {
    const resp = await getDeviceStateList({
      page: currentPage,
      pageSize: currentPageSize,
      status: tabKey,
      ...querysData,
    });
    if (isSuccessApi(resp)) {
      toListDomByData(resp.data.results);
      setTabs(() => {
        const finalArr = [];
        JSON.parse(JSON.stringify(deviceStateEnums)).forEach((item) => {
          switch (item.key) {
            case '1':
              item.label = `${deviceStateEnums[1].label}（${resp.data.onlineCount}）`;
              break;
            case '2':
              item.label = `${deviceStateEnums[2].label}（${resp.data.outlineCount}）`;
              break;
            case '3':
              item.label = `${deviceStateEnums[3].label}（${resp.data.processCount}）`;
              break;
            case '4':
              item.label = `${deviceStateEnums[4].label}（${resp.data.errorCount}）`;
              break;
            case '0':
            default:
              item.label = `${deviceStateEnums[0].label}（${resp.data.count}）`;
              break;
          }
          finalArr.push(item);
        });
        return finalArr;
      });
      setTotal(() => {
        switch (tabKey) {
          case '1':
            return resp.data.onlineCount;
          case '2':
            return resp.data.outlineCount;
          case '3':
            return resp.data.processCount;
          case '4':
            return resp.data.errorCount;
          default:
            return resp.data.count;
        }
      });
    }
  }
  // TODO 切换时页码没有显示第一页
  const changeTabMode = (key: string) => {
    setTabKey(key);
    setCurrentPage(1);
    console.log(key);
  };
  // function reloadList() {
  //   setTabKey('0');
  //   setCurrentPage(1);
  // }

  // 初始化加载 & 筛选查询
  useEffect(() => {
    fetchData();
  }, [tabKey, currentPageSize, currentPage, querysData]);

  return (
    <div className="flex-1 bs_server_state_page bs_state_page gn_head_card">
      <div className="gn_table_query_filter">
        <ProForm
          className="gn_search_from"
          form={form}
          layout="horizontal"
          submitter={{
            render: () => (
              <div style={{ textAlign: 'center', marginLeft: 12 }}>
                <CommButton
                  type="primary"
                  htmlType="submit"
                  prevIcon={<SearchIcon />}
                  buttonLabel={
                    <FormattedMessage id="pages.searchTable.search" defaultMessage="查询" />
                  }
                ></CommButton>
                <CommButton
                  style={{ marginLeft: 12 }}
                  htmlType="button"
                  prevIcon={<ResetIcon />}
                  buttonLabel={
                    <FormattedMessage id="pages.searchTable.reset" defaultMessage="重置" />
                  }
                  onClick={() => {
                    form.resetFields(); // 点击重置按钮时重置表单数据
                    setQuerysData(() => {}); // 清空筛选项
                  }}
                ></CommButton>
              </div>
            ),
          }}
          onFinish={async (values) => {
            console.log(values, 'filter_finish_values');
            setQuerysData(() => values);

            return true;
          }}
        >
          {/* //TODO 缺失筛选条件设备组 树形选择*/}
          <ProFormSelect
            width={300}
            name="deviceType"
            label={
              <FormattedMessage
                id="device_group_list.table.list.deviceType"
                defaultMessage="设备分类"
              />
            }
            placeholder={`${intl.formatMessage({
              id: 'common.please_select',
              defaultMessage: '$$$',
            })}${intl.formatMessage({
              id: 'device_group_list.table.list.deviceType',
              defaultMessage: '设备分类',
            })}`}
            showSearch
            debounceTime={500}
            request={async () => {
              const { data } = await getDictDeviceType();
              return data?.results?.map((v: Record<string, any>) => {
                return { ...v, label: v.name, value: v.id };
              });
            }}
          />
        </ProForm>
      </div>

      <ProCard className="gn_card pb-[16px]">
        <div className="bs_server_state_box">
          <Tabs
            className="gn_tabs"
            activeKey={tabKey}
            items={tabs}
            onChange={(key) => {
              changeTabMode(key);
            }}
          ></Tabs>
          <ProList<any>
            className="gn_pro_list"
            ghost={true}
            rowKey={'id'}
            itemCardProps={{
              ghost: true,
              bodyStyle: { padding: 0, margin: 0 },
            }}
            cardProps={{
              bodyStyle: {
                background: 'transparent',
                margin: '-4px 0',
              },
            }}
            pagination={{
              ...proTablePaginationOptions,
              page: currentPage,
              pageSize: currentPageSize,
              total: total || 0, // 指定总条目数
              onChange: (page, pageSize) => {
                setCurrentPageSize(pageSize);
                setCurrentPage(page);
              },
            }}
            rowSelection={false}
            grid={{ gutter: 16, xs: 1, md: 2, lg: 3, xl: 4, xxl: 5 }}
            metas={{
              content: {},
            }}
            dataSource={serverList}
          />
        </div>
      </ProCard>

      <DetailDeviceState
        detailOpen={detailOpen}
        info={currentRow}
        closeModal={() => {
          setDetailOpen(false);
        }}
      />
    </div>
  );
};
export default DeviceSate;
