/*
 * @Author: donghao donghao@supervision.ltd
 * @Date: 2024-05-07 13:38:03
 * @LastEditors: donghao donghao@supervision.ltd
 * @LastEditTime: 2024-05-13 11:30:19
 * @FilePath: \general-ai-platform-web\src\pages\Business\BusinessState\index.tsx
 * @Description: 设备服务器状态  一级关键词 businessState（bs）
 * @交互说明
 * 1、服务器状态列表的查看、新增、编辑、删除
 * 2、服务器状态基本信息展示
 */
import { CommButton, TextButton } from '@/components/Button';
import IsDelete from '@/components/TableActionCard/isDelete';
import { serverStateEnums } from '@/enums/server';
import { getServerStateList } from '@/services/testApi/businessState';
import { isSuccessApi } from '@/utils/forApi';
import { ProCard, ProList } from '@ant-design/pro-components';
import { FormattedMessage } from '@umijs/max';
import { Tabs } from 'antd';
import { useEffect, useState } from 'react';
import { proTablePaginationOptions } from '../../../../config/defaultTable';
import CreateServerForm from './components/createServerForm';
import DetailServerState from './components/detailServerState';
import ServerStateCard from './components/serverStateCard';
import './index.less';

const BusinessState: React.FC = () => {
  /**state */
  // 列表
  const [serverList, setServerList] = useState<Record<string, any>[]>([]); // 列表数据
  const [currentRow, setCurrentRow] = useState<Record<string, any>>();
  const [currentPageSize, setCurrentPageSize] = useState<number>(8);
  const [currentPage, setCurrentPage] = useState<number>(1);
  const [total, setTotal] = useState<number>(1);
  const [createModalOpen, setCreateModalOpen] = useState<boolean>(false);
  // 详情展示
  const [detailOpen, setDetailOpen] = useState<boolean>(false);

  // 切换筛选
  const [tabKey, setTabKey] = useState<string>(serverStateEnums[0].key);
  const [tabs, setTabs] = useState<DICTENUM.DICT_TAB_ITEM[]>([]);
  // 新增
  const handleCreateModal = () => {
    setCreateModalOpen(!createModalOpen);
  };

  // 将数据组装成reactDom
  function toListDomByData(record) {
    let startList = [...record];
    let finalList = startList.map((item) => ({
      content: (
        <ServerStateCard
          info={item}
          fetchDetail={() => {
            setCurrentRow(item);
            setDetailOpen(true);
          }}
          renderActions={[
            {
              key: 'update',
              renderDom: (
                <span
                  onClick={(e) => {
                    e.stopPropagation();
                    setCurrentRow(item);
                    console.log('编辑');
                  }}
                >
                  <TextButton
                    className="text-[12px]"
                    buttonLabel={
                      <FormattedMessage id="pages.searchTable.update" defaultMessage="编辑" />
                    }
                    buttonType="primary"
                  ></TextButton>
                </span>
              ),
            },
            {
              key: 'destroy',
              renderDom: (
                <span>
                  <IsDelete
                    deleteNextText={
                      <FormattedMessage id="pages.searchTable.destroy" defaultMessage="删除" />
                    }
                    buttonRender={
                      <TextButton
                        fontSize={12}
                        buttonLabel={
                          <FormattedMessage id="pages.searchTable.destroy" defaultMessage="删除" />
                        }
                        buttonType="danger"
                      ></TextButton>
                    }
                    deleteApi={() => {
                      // TODO 调用删除接口
                      // handleDestroy(record).then(() => {});
                    }}
                  />
                </span>
              ),
            },
          ]}
        ></ServerStateCard>
      ),
    }));
    setServerList(finalList);
    console.log(finalList, 'toListDomByData_finalList');
  }

  // 企业列表数据api
  async function fetchData() {
    const resp = await getServerStateList({
      page: currentPage,
      pageSize: currentPageSize,
      status: tabKey,
    });
    if (isSuccessApi(resp)) {
      toListDomByData(resp.data.results);
      setTabs(() => {
        const finalArr = [];
        JSON.parse(JSON.stringify(serverStateEnums)).forEach((item) => {
          switch (item.key) {
            case '0':
              item.label = `${serverStateEnums[0].label}（${resp.data.count}）`;
              break;
            case '1':
              item.label = `${serverStateEnums[1].label}（${resp.data.onlineCount}）`;
              break;
            case '2':
              item.label = `${serverStateEnums[2].label}（${resp.data.outlineCount}）`;
              break;
          }
          finalArr.push(item);
        });
        return finalArr;
      });
      setTotal(() => {
        switch (tabKey) {
          case '1':
            return resp.data.onlineCount;
          case '2':
            return resp.data.outlineCount;
          default:
            return resp.data.count;
        }
      });
    }
  }
  // TODO 切换时页码没有显示第一页
  const changeTabMode = (key: string) => {
    setTabKey(key);
    setCurrentPage(1);
    console.log(key);
  };
  function reloadList() {
    setTabKey('0');
    setCurrentPage(1);
  }

  // 初始化加载 & 筛选查询
  useEffect(() => {
    fetchData();
  }, [tabKey, currentPageSize, currentPage]);

  return (
    <div className="flex-1 bs_server_state_page bs_state_page gn_head_card">
      <ProCard className="gn_card pb-[16px]">
        <div className="bs_server_state_box">
          <Tabs
            className="gn_tabs"
            activeKey={tabKey}
            items={tabs}
            onChange={(key) => {
              changeTabMode(key);
            }}
          ></Tabs>
          <div className="flex justify-end pb-[12px]">
            <CommButton
              type="primary"
              onClick={() => {
                setCreateModalOpen(true);
              }}
              buttonLabel={
                <FormattedMessage id="server_state.table.list.add" defaultMessage="新建" />
              }
            ></CommButton>
          </div>
          <ProList<any>
            className="gn_pro_list"
            ghost={true}
            rowKey={'id'}
            itemCardProps={{
              ghost: true,
              bodyStyle: { padding: 0, margin: 0 },
            }}
            cardProps={{
              bodyStyle: {
                background: 'transparent',
                margin: '-4px 0',
              },
            }}
            pagination={{
              ...proTablePaginationOptions,
              page: currentPage,
              pageSize: currentPageSize,
              total: total || 0, // 指定总条目数
              onChange: (page, pageSize) => {
                setCurrentPageSize(pageSize);
                setCurrentPage(page);
              },
            }}
            rowSelection={false}
            grid={{ gutter: 16, xs: 1, md: 2, lg: 3, xl: 4, xxl: 5 }}
            metas={{
              content: {},
            }}
            dataSource={serverList}
          />
        </div>
      </ProCard>
      <CreateServerForm
        createModalOpen={createModalOpen}
        handleModal={handleCreateModal}
        reload={reloadList}
      />
      <DetailServerState
        detailOpen={detailOpen}
        info={currentRow}
        closeModal={() => {
          setDetailOpen(false);
        }}
      />
    </div>
  );
};
export default BusinessState;
