import { getDictDeviceType } from '@/services/testApi/dict';
import {
  ModalForm,
  ProForm,
  ProFormSelect,
  ProFormText,
  ProFormTextArea,
} from '@ant-design/pro-components';
import { FormattedMessage, useIntl } from '@umijs/max';
import { Form } from 'antd';
import React from 'react';
import {
  proFormSmallItemStyleProps,
  proFormSmallModelWidth,
} from '../../../../../config/defaultForm';
// @ts-ignore

export type CreateDeviceFormProps = {
  createModalOpen: boolean;
  handleModal: () => void;
  reload: any;
};
const CreateDeviceForm: React.FC<CreateDeviceFormProps> = (props) => {
  const intl = useIntl();
  // const [isAuto, setIsAuto] = useState(true);
  const [form] = Form.useForm<API.ModelCategory>();

  return (
    <ModalForm<API.ModelCategory>
      className="gn_modal_form gn_form"
      width={proFormSmallModelWidth}
      title={intl.formatMessage({
        id: 'device_group_list.table.list.add',
        defaultMessage: '新建',
      })}
      open={props.createModalOpen}
      form={form}
      autoFocusFirstInput
      modalProps={{
        destroyOnClose: true,
        onCancel: () => props.handleModal(),
      }}
      submitTimeout={2000}
      onFinish={async (values) => {
        console.log(values, 'add_finish_values');
        // TODO 对接新增接口
        // postModelCategoryCreateModelCategory(values)
        //   .then(() => {
        //     message.success(intl.formatMessage({ id: 'common.success', defaultMessage: '$$$' }));
        //     props.reload();
        //   })
        //   .catch(() => {
        //     message.error(intl.formatMessage({ id: 'common.failure', defaultMessage: '$$$' }));
        //   });
        props.handleModal();
        return true;
      }}
    >
      <ProForm.Group>
        <ProFormText
          width={proFormSmallItemStyleProps.column2Width}
          name="name"
          label={
            <FormattedMessage id="device_group_list.table.list.name" defaultMessage="设备名称" />
          }
          placeholder={`${intl.formatMessage({
            id: 'common.please_input',
            defaultMessage: '$$$',
          })}${intl.formatMessage({
            id: 'device_group_list.table.list.name',
            defaultMessage: '$$$',
          })}`}
          required={true}
          rules={[
            {
              required: true,
              message: (
                <FormattedMessage
                  id="device_group_list.table.list.rule.required.name"
                  defaultMessage="名称必填"
                />
              ),
            },
          ]}
        />
        <ProFormText
          width={proFormSmallItemStyleProps.column2Width}
          name="deviceSite"
          label={
            <FormattedMessage
              id="device_group_list.table.list.deviceSite"
              defaultMessage="设备位置"
            />
          }
          placeholder={`${intl.formatMessage({
            id: 'common.please_input',
            defaultMessage: '$$$',
          })}${intl.formatMessage({
            id: 'device_group_list.table.list.deviceSite',
            defaultMessage: '$$$',
          })}`}
        />

        <ProFormSelect
          width={proFormSmallItemStyleProps.column2Width}
          name="deviceType"
          label={
            <FormattedMessage
              id="device_group_list.table.list.deviceType"
              defaultMessage="设备分类"
            />
          }
          placeholder={`${intl.formatMessage({
            id: 'common.please_select',
            defaultMessage: '$$$',
          })}${intl.formatMessage({
            id: 'device_group_list.table.list.deviceType',
            defaultMessage: '$$$',
          })}`}
          showSearch
          debounceTime={500}
          request={async () => {
            const { data } = await getDictDeviceType();
            return data?.results?.map((v: Record<string, any>) => {
              return { ...v, label: v.name, value: v.id };
            });
          }}
        />
        <ProFormText
          width={proFormSmallItemStyleProps.column2Width}
          name="deviceModel"
          label={
            <FormattedMessage
              id="device_group_list.table.list.deviceModel"
              defaultMessage="设备型号"
            />
          }
          placeholder={`${intl.formatMessage({
            id: 'common.please_input',
            defaultMessage: '$$$',
          })}${intl.formatMessage({
            id: 'device_group_list.table.list.deviceModel',
            defaultMessage: '$$$',
          })}`}
        />

        <ProFormText
          width={proFormSmallItemStyleProps.width}
          name="deviceParams"
          label={
            <FormattedMessage
              id="device_group_list.table.list.deviceParams"
              defaultMessage="设备参数"
            />
          }
          placeholder={`${intl.formatMessage({
            id: 'common.please_input',
            defaultMessage: '$$$',
          })}${intl.formatMessage({
            id: 'device_group_list.table.list.deviceParams',
            defaultMessage: '$$$',
          })}`}
        />

        <ProFormTextArea
          width={proFormSmallItemStyleProps.width}
          name="remark"
          label={
            <FormattedMessage id="device_group_list.table.list.remark" defaultMessage="备注" />
          }
          placeholder={`${intl.formatMessage({
            id: 'common.please_input',
            defaultMessage: '$$$',
          })}${intl.formatMessage({
            id: 'device_group_list.table.list.remark',
            defaultMessage: '$$$',
          })}`}
        />
      </ProForm.Group>
    </ModalForm>
  );
};
export default CreateDeviceForm;
