// import { postModelCategoryCreateModelCategory } from '@/services/resource/ModelCategory';
import { ModalForm, ProForm, ProFormText, ProFormTextArea } from '@ant-design/pro-components';
import { FormattedMessage, useIntl } from '@umijs/max';
import { Form } from 'antd';
import React from 'react';
import {
  proFormSmallItemStyleProps,
  proFormSmallModelWidth,
} from '../../../../../config/defaultForm';
// @ts-ignore

export type CreateFormProps = {
  createModalOpen: boolean;
  handleModal: () => void;
  parentInfo?: Record<string, any>;
  reload: any;
};
const CreateForm: React.FC<CreateFormProps> = (props) => {
  const intl = useIntl();
  // const [isAuto, setIsAuto] = useState(true);
  const [form] = Form.useForm<API.ModelCategory>();

  return (
    <ModalForm<API.ModelCategory>
      className="gn_modal_form gn_form"
      width={proFormSmallModelWidth}
      title={intl.formatMessage({
        id: 'device_group.tree_node.createForm.add',
        defaultMessage: '新建',
      })}
      open={props.createModalOpen}
      form={form}
      autoFocusFirstInput
      modalProps={{
        destroyOnClose: true,
        onCancel: () => props.handleModal(),
      }}
      submitTimeout={2000}
      onFinish={async (values) => {
        console.log(values, 'add_finish_values');
        // TODO 对接新增接口
        // postModelCategoryCreateModelCategory(values)
        //   .then(() => {
        //     message.success(intl.formatMessage({ id: 'common.success', defaultMessage: '$$$' }));
        //     props.reload();
        //   })
        //   .catch(() => {
        //     message.error(intl.formatMessage({ id: 'common.failure', defaultMessage: '$$$' }));
        //   });
        props.handleModal();
        return true;
      }}
    >
      <ProForm.Group>
        <ProFormText
          width={proFormSmallItemStyleProps.column2Width}
          name="name"
          label={<FormattedMessage id="device_group.tree_node.name" defaultMessage="名称" />}
          placeholder={`${intl.formatMessage({
            id: 'common.please_input',
            defaultMessage: '$$$',
          })}${intl.formatMessage({
            id: 'device_group.tree_node.name',
            defaultMessage: '$$$',
          })}`}
          required={true}
          rules={[
            {
              required: true,
              message: (
                <FormattedMessage
                  id="device_group.tree_node.rule.required.name"
                  defaultMessage="名称必填"
                />
              ),
            },
          ]}
        />
        <ProFormText
          width={proFormSmallItemStyleProps.column2Width}
          name="fatherName"
          label={
            <FormattedMessage id="device_group.tree_node.fatherName" defaultMessage="上级节点" />
          }
          placeholder={`${intl.formatMessage({
            id: 'common.please_input',
            defaultMessage: '$$$',
          })}${intl.formatMessage({
            id: 'device_group.tree_node.fatherName',
            defaultMessage: '$$$',
          })}`}
          disabled
        />
        <ProFormText
          width={proFormSmallItemStyleProps.width}
          name="address"
          label={<FormattedMessage id="device_group.tree_node.address" defaultMessage="地址" />}
          placeholder={`${intl.formatMessage({
            id: 'common.please_input',
            defaultMessage: '$$$',
          })}${intl.formatMessage({
            id: 'device_group.tree_node.address',
            defaultMessage: '$$$',
          })}`}
        />

        <ProFormText
          width={proFormSmallItemStyleProps.column2Width}
          name="lon"
          label={<FormattedMessage id="device_group.tree_node.lon" defaultMessage="经度" />}
          placeholder={`${intl.formatMessage({
            id: 'common.please_input',
            defaultMessage: '$$$',
          })}${intl.formatMessage({
            id: 'device_group.tree_node.lon',
            defaultMessage: '$$$',
          })}`}
        />
        <ProFormText
          width={proFormSmallItemStyleProps.column2Width}
          name="lat"
          label={<FormattedMessage id="device_group.tree_node.lat" defaultMessage="纬度" />}
          placeholder={`${intl.formatMessage({
            id: 'common.please_input',
            defaultMessage: '$$$',
          })}${intl.formatMessage({
            id: 'device_group.tree_node.lat',
            defaultMessage: '$$$',
          })}`}
        />

        <ProFormText
          width={proFormSmallItemStyleProps.column2Width}
          name="managerName"
          label={
            <FormattedMessage id="device_group.tree_node.managerName" defaultMessage="负责人" />
          }
          placeholder={`${intl.formatMessage({
            id: 'common.please_input',
            defaultMessage: '$$$',
          })}${intl.formatMessage({
            id: 'device_group.tree_node.managerName',
            defaultMessage: '$$$',
          })}`}
        />
        <ProFormText
          width={proFormSmallItemStyleProps.column2Width}
          name="managerPhone"
          label={
            <FormattedMessage id="device_group.tree_node.managerPhone" defaultMessage="联系方式" />
          }
          placeholder={`${intl.formatMessage({
            id: 'common.please_input',
            defaultMessage: '$$$',
          })}${intl.formatMessage({
            id: 'device_group.tree_node.managerPhone',
            defaultMessage: '$$$',
          })}`}
        />
        <ProFormTextArea
          width={proFormSmallItemStyleProps.width}
          name="remark"
          label={<FormattedMessage id="device_group.tree_node.remark" defaultMessage="简介" />}
          placeholder={`${intl.formatMessage({
            id: 'common.please_input',
            defaultMessage: '$$$',
          })}${intl.formatMessage({
            id: 'device_group.tree_node.remark',
            defaultMessage: '$$$',
          })}`}
        />
      </ProForm.Group>
    </ModalForm>
  );
};
export default CreateForm;
