import { getModelRuntimeLibFilesList } from '@/services/testApi/model';
import {
  ProForm,
  ProFormInstance,
  ProFormList,
  ProFormSelect,
  ProFormText,
  ProFormUploadDragger,
  StepsForm,
} from '@ant-design/pro-components';
import { FormListActionType } from '@ant-design/pro-form/lib';

import { FormattedMessage, useIntl } from '@umijs/max';
import { Button, Modal, UploadFile, message } from 'antd';
import yaml from 'js-yaml';
import React, { useEffect, useRef, useState } from 'react';
import {
  proFormSmallItemStyleProps,
  proFormSmallModelWidth,
  proFormStepsFormProps,
} from '../../../../../config/defaultForm';
// import {beforeUploadFile} from "@/utils/common";
// @ts-ignore

export type FormValueType = {
  target?: string;
  template?: string;
  type?: string;
  time?: string;
  frequency?: string;
} & Partial<API.ModelVersion>;

export type CreateModelParamsProps = {
  createModalOpen: boolean;
  handleModal: () => void;
  values: Partial<API.ModelVersion>;
  reload: any;
  currentDefaultFieldsData?: Record<string, any>;
};
const waitTime = (time: number = 100) => {
  return new Promise((resolve) => {
    setTimeout(() => {
      resolve(true);
    }, time);
  });
};
// interface ProjectConfig {
//   params: Array<object>;
// }
const CreateModelParams: React.FC<CreateModelParamsProps> = (props) => {
  const actionFormListRef = useRef<
    FormListActionType<{
      name: string;
    }>
  >();

  const intl = useIntl();
  const [isHasModelFkId, setIsHasModelFkId] = useState<boolean>(false);

  const [dataFormList] = useState<any>([]);
  const dataFormListRef = useRef(dataFormList);
  const [fileList, setFileList] = useState<UploadFile<any>[]>([]);

  // const [form] = Form.useForm<API.ModelVersion>();
  const [current, setCurrent] = useState(0);
  const formRef = useRef<ProFormInstance>();
  const [filePath] = useState('');

  const [openFiles, setOpenFiles] = useState<boolean>(false);

  const handleFileChange = ({ file }: { file: UploadFile }) => {
    let curFile: any;

    switch (file.status) {
      case 'uploading':
      case 'done':
        curFile = [file];
        break;

      case 'removed':
      default:
        curFile = [];
        break;
    }

    setFileList([...curFile]);
  };
  useEffect(() => {
    if (props.currentDefaultFieldsData) {
      // 如果是在模型详情新增版本，ModelFkId不可编辑
      console.log(props.values, isHasModelFkId, 'currentDefaultFieldsData');
      setIsHasModelFkId(true);
    } else {
      setIsHasModelFkId(false);
    }
  }, []);
  return (
    <StepsForm<{
      name: string;
    }>
      stepsProps={proFormStepsFormProps.stepsProps}
      current={current}
      onCurrentChange={setCurrent}
      formProps={{
        validateMessages: {
          required: '此项为必填项',
        },
      }}
      stepsFormRender={(dom, submitter) => {
        return (
          <Modal
            className="gn_model_steps_form"
            title={
              <FormattedMessage id="base_model.stepForm.add.title" defaultMessage="基础模型配置" />
            }
            width={proFormSmallModelWidth}
            onCancel={() => {
              setCurrent(0);
              formRef.current?.resetFields();
              setFileList([]);
              props.handleModal();
            }}
            open={props.createModalOpen}
            footer={submitter}
            destroyOnClose
          >
            {dom}
          </Modal>
        );
      }}
    >
      {/* 参数配置 businessConfig */}
      <StepsForm.StepForm<{
        config: string;
      }>
        className="gn_form"
        name="businessConfig"
        title={
          <FormattedMessage id="base_model.stepForm.businessConfig" defaultMessage="参数配置" />
        }
        stepProps={{
          description: (
            <FormattedMessage
              id="base_model.stepForm.businessConfig.description"
              defaultMessage="参数配置"
            />
          ),
        }}
        onFinish={async (values: any) => {
          setFileList([]);
          let formData = formRef.current?.getFieldsValue();
          if (formData?.modelFkId) {
            await waitTime(500);
            formData.modelConfig = { params: values?.params || [] };
            if (filePath) {
              formData.path = filePath;
            }
            // postModelVersionCreateModelVersion(formData)
            //   .then(() => {
            //     message.success(
            //       intl.formatMessage({ id: 'common.success', defaultMessage: '$$$' }),
            //     );
            //     props.handleModal();
            //     props.reload();
            //   })
            //   .catch(() => {
            //     message.error(intl.formatMessage({ id: 'common.failure', defaultMessage: '$$$' }));
            //     return false;
            //   });
          }
          return true;
        }}
      >
        {/*  // TODO 上传文案需要和UI稿对比   */}
        <ProFormUploadDragger
          width={proFormSmallItemStyleProps.width}
          max={1}
          label={<span className="font-bold">配置文件上传</span>}
          value={fileList}
          name="dragger"
          fieldProps={{
            onChange: handleFileChange,
            onRemove: () => {
              let index_ids = actionFormListRef.current?.getList()?.map((v, i) => {
                return i;
              });
              actionFormListRef.current?.remove(index_ids || []);
            },
            beforeUpload: (file) => {
              if (
                !file.name.endsWith('.yaml') &&
                !file.name.endsWith('.yml') &&
                !file.name.endsWith('.json')
              ) {
                message.error('请上传yaml或json文件').then(() => {});
                return false;
              } else {
                let parsedData = {};
                file
                  .text()
                  .then((text) => {
                    if (file.name.endsWith('.yaml') || file.name.endsWith('.yml')) {
                      parsedData = yaml.load(text) as Record<string, unknown>;
                    }
                    if (file.name.endsWith('.json')) {
                      parsedData = JSON.parse(text) as Record<string, unknown>;
                    }
                    if (Object.keys(parsedData).length > 0) {
                      dataFormListRef.current = Object.entries(parsedData).map(([key, value]) => ({
                        name: key,
                        default: value,
                      }));

                      dataFormListRef.current.forEach((v: any, i: number) => {
                        actionFormListRef.current?.add(v, i);
                      });
                    }
                    return true;
                  })
                  .catch(() => {
                    return false;
                  });
              }
            },
          }}
        />

        {/*  // TODO label字重与上面统一, 操作按钮需要与输入框对齐   */}
        <ProFormList
          name="params"
          label={
            <div>
              {' '}
              <span className="font-bold">模型参数</span>
              <p style={{ color: '#666666' }}>
                暂未上传模型配置文件，可根据业务需求手动添加参数字段~
              </p>
            </div>
          }
          actionRef={actionFormListRef}
          itemContainerRender={(doms) => {
            return <ProForm.Group>{doms}</ProForm.Group>;
          }}
          alwaysShowItemLabel
        >
          {() => {
            return (
              <>
                <ProFormText key="name" name="name" label="键名" />
                <ProFormText key="default" name="default" label="默认值" />
              </>
            );
          }}
        </ProFormList>
      </StepsForm.StepForm>
      {/* 运行库选择 runtimeLib */}
      <StepsForm.StepForm<{
        name: string;
      }>
        className="gn_form"
        name="runtimeLib"
        formRef={formRef}
        title={<FormattedMessage id="base_model.stepForm.runtimeLib" defaultMessage="版本信息" />}
        stepProps={{
          description: (
            <FormattedMessage
              id="base_model.stepForm.runtimeLib.description"
              defaultMessage="填写版本基础信息"
            />
          ),
        }}
        onFinish={async () => {
          // setFormData(formRef.current?.getFieldsValue());
          await waitTime(500);
          return true;
        }}
      >
        <ProForm.Group>
          <ProFormText
            width={proFormSmallItemStyleProps.column2Width - 40}
            name="ip"
            initialValue={'http://127.0.0.1'}
            label={
              <FormattedMessage id="model_runtimeLib.list.table.form.IP" defaultMessage="IP地址" />
            }
            placeholder={`${intl.formatMessage({
              id: 'common.please_input',
              defaultMessage: '$$$',
            })}${intl.formatMessage({
              id: 'model_runtimeLib.list.table.form.IP',
              defaultMessage: '$$$',
            })}`}
            required={true}
            rules={[
              {
                required: true,
                message: (
                  <FormattedMessage
                    id="model_runtimeLib.list.table.form.rule.required.IP"
                    defaultMessage="name is required"
                  />
                ),
              },
            ]}
          />
          <ProFormText
            width={proFormSmallItemStyleProps.column2Width - 40}
            name="port"
            initialValue={'80'}
            label={
              <FormattedMessage id="model_runtimeLib.list.table.form.port" defaultMessage="端口" />
            }
            placeholder={`${intl.formatMessage({
              id: 'common.please_input',
              defaultMessage: '$$$',
            })}${intl.formatMessage({
              id: 'model_runtimeLib.list.table.form.port',
              defaultMessage: '$$$',
            })}`}
            required={true}
            rules={[
              {
                required: true,
                message: (
                  <FormattedMessage
                    id="model_runtimeLib.list.table.form.rule.required.port"
                    defaultMessage="name is required"
                  />
                ),
              },
            ]}
          />
          <Button
            className="search_ip_port_btn"
            style={{ marginTop: '30px' }}
            onClick={() => {
              const { ip, port } = formRef.current?.getFieldsValue();
              if (ip && port) {
                // 访问接口拿数据
                setOpenFiles(true);
              } else {
                message.error('请填写IP和端口');
              }

              console.log(formRef.current?.getFieldsValue(), 'searchIP');
            }}
          >
            查询
          </Button>
        </ProForm.Group>
        {openFiles ? (
          <ProFormSelect
            width={proFormSmallItemStyleProps.width}
            name="fileName"
            placeholder={`${intl.formatMessage({
              id: 'common.please_select',
              defaultMessage: '$$$',
            })}${intl.formatMessage({
              id: 'model_runtimeLib.list.table.form.fileName',
              defaultMessage: '$$$',
            })}`}
            required={true}
            showSearch
            debounceTime={500}
            request={async () => {
              const { data } = await getModelRuntimeLibFilesList();
              return data?.results?.map((v: Record<string, any>) => {
                return { ...v, label: v.name, value: v.id };
              });
            }}
            rules={[
              {
                required: true,
                message: (
                  <FormattedMessage
                    id="model_runtimeLib.list.table.form.rule.required.fileName"
                    defaultMessage="name is required"
                  />
                ),
              },
            ]}
          />
        ) : (
          <></>
        )}
      </StepsForm.StepForm>
      {/* 模型参数配置 modelConfig */}
      <StepsForm.StepForm<{
        config: string;
      }>
        className="gn_form"
        name="modelConfig"
        title={<FormattedMessage id="base_model.stepForm.modelConfig" defaultMessage="参数配置" />}
        stepProps={{
          description: (
            <FormattedMessage
              id="base_model.stepForm.modelConfig.description"
              defaultMessage="参数配置"
            />
          ),
        }}
        onFinish={async (values: any) => {
          setFileList([]);
          let formData = formRef.current?.getFieldsValue();
          if (formData?.modelFkId) {
            await waitTime(500);
            formData.modelConfig = { params: values?.params || [] };
            if (filePath) {
              formData.path = filePath;
            }
            // postModelVersionCreateModelVersion(formData)
            //   .then(() => {
            //     message.success(
            //       intl.formatMessage({ id: 'common.success', defaultMessage: '$$$' }),
            //     );
            //     props.handleModal();
            //     props.reload();
            //   })
            //   .catch(() => {
            //     message.error(intl.formatMessage({ id: 'common.failure', defaultMessage: '$$$' }));
            //     return false;
            //   });
          }
          return true;
        }}
      >
        {/*  // TODO 上传文案需要和UI稿对比   */}
        <ProFormUploadDragger
          width={proFormSmallItemStyleProps.width}
          max={1}
          label={<span className="font-bold">模型文件上传</span>}
          value={fileList}
          name="dragger"
          fieldProps={{
            onChange: handleFileChange,
            onRemove: () => {
              let index_ids = actionFormListRef.current?.getList()?.map((v, i) => {
                return i;
              });
              actionFormListRef.current?.remove(index_ids || []);
            },
            beforeUpload: (file) => {
              if (
                !file.name.endsWith('.yaml') &&
                !file.name.endsWith('.yml') &&
                !file.name.endsWith('.json')
              ) {
                message.error('请上传yaml或json文件').then(() => {});
                return false;
              } else {
                let parsedData = {};
                file
                  .text()
                  .then((text) => {
                    if (file.name.endsWith('.yaml') || file.name.endsWith('.yml')) {
                      parsedData = yaml.load(text) as Record<string, unknown>;
                    }
                    if (file.name.endsWith('.json')) {
                      parsedData = JSON.parse(text) as Record<string, unknown>;
                    }
                    if (Object.keys(parsedData).length > 0) {
                      dataFormListRef.current = Object.entries(parsedData).map(([key, value]) => ({
                        name: key,
                        default: value,
                      }));

                      dataFormListRef.current.forEach((v: any, i: number) => {
                        actionFormListRef.current?.add(v, i);
                      });
                    }
                    return true;
                  })
                  .catch(() => {
                    return false;
                  });
              }
            },
          }}
        />

        {/*  // TODO label字重与上面统一, 操作按钮需要与输入框对齐   */}
        <ProFormList
          name="params"
          label={
            <div>
              {' '}
              <span className="font-bold">模型参数</span>
              <p style={{ color: '#666666' }}>暂未上传模型文件，可根据业务需求手动添加参数字段~</p>
            </div>
          }
          actionRef={actionFormListRef}
          itemContainerRender={(doms) => {
            return <ProForm.Group>{doms}</ProForm.Group>;
          }}
          alwaysShowItemLabel
        >
          {() => {
            return (
              <>
                <ProFormText key="name" name="name" label="键名" />
                <ProFormText key="default" name="default" label="默认值" />
              </>
            );
          }}
        </ProFormList>
      </StepsForm.StepForm>
    </StepsForm>
  );
};
export default CreateModelParams;
