/*
 * @Author: donghao donghao@supervision.ltd
 * @Date: 2024-04-22 15:23:36
 * @LastEditors: donghao donghao@supervision.ltd
 * @LastEditTime: 2024-05-10 15:34:31
 * @FilePath: \general-ai-platform-web\src\pages\Business\DeviceGroup\components\deviceList.tsx
 * @Description: 设备节点设置 关键词 deviceGroup（dg）
 * @交互说明
 * 3、设备列表分页查看、新建、编辑、删除、设备分类、基础模型配置
 * 4、业务模型部
 * 5、企业告警设置122
 */
import InnerPageBack from '@/components/Back/innerPageBack';
import { getDictDeviceType } from '@/services/testApi/dict';

import TableActionCard from '@/components/TableActionCard';
import { getDeviceListByGroup } from '@/services/testApi/device';
import { ProTable } from '@ant-design/pro-components';
import { Access, FormattedMessage, history, useAccess, useIntl } from '@umijs/max';
import { Button } from 'antd';
import { useRef, useState } from 'react';

import { proTablePaginationOptions } from '../../../../../config/defaultTable';

import CategorizeUpdate from '@/components/CategorizeUpdate';
import IsDelete from '@/components/TableActionCard/isDelete';
import CreateDeviceForm from './createDeviceForm';
import ModelSetting from './modelSetting';

type DeviceListProps = {
  info: Record<string, any>;
};

const DeviceList: React.FC<DeviceListProps> = () => {
  /**state */
  const access = useAccess();
  // eslint-disable-next-line react-hooks/rules-of-hooks
  const intl = useIntl();
  const actionRef = useRef<ActionType>();

  const [createModalOpen, setCreateModalOpen] = useState<boolean>(false);
  const [currentRow, setCurrentRow] = useState<Record<string, any>>({});

  //  动态设置每页数量
  const [currentPageSize, setCurrentPageSize] = useState<number>(10);
  // 设置分类
  const [deviceTypeOpen, setDeviceTypeOpen] = useState<boolean>(false);

  // 设置行业分类
  const handleSetDeviceType = () => {
    setDeviceTypeOpen(!deviceTypeOpen);
  };

  // 基础模型设置 isSettingOpen
  const [isSettingOpen, setIsSettingOpen] = useState<boolean>(false);

  /**新增 编辑 删除 */
  // 新增
  const handleCreateModal = () => {
    setCreateModalOpen(!createModalOpen);
  };

  function reloadList() {
    actionRef.current?.reload();
  }

  const columns: ProColumns<Record<string, any>>[] = [
    {
      title: <FormattedMessage id="device_group_list.table.list.name" defaultMessage="设备名称" />,
      dataIndex: 'name',
      hideInSearch: true,
      // width: 80,
      //   key: 'fixedName',
      //   fixed: 'left',
    },
    {
      title: (
        <FormattedMessage id="device_group_list.table.list.deviceType" defaultMessage="设备类型" />
      ),
      dataIndex: 'deviceType',
      hideInSearch: true,
      // width: 120,
    },
    {
      title: (
        <FormattedMessage id="device_group_list.table.list.isEnable" defaultMessage="模型部署" />
      ),
      dataIndex: 'isEnable',
      hideInSearch: true,
      // width: 80,
      render: (dom, record) => {
        return (
          <div
            className={`gn_list_type_tag flex items-center justify-center ${
              record.isEnable ? 'active1' : 'active2'
            }`}
          >
            <span className="dot"></span>
            <span>
              {record.isEnable ? (
                <FormattedMessage
                  id="device_group_list.table.list.deployed.isEnable"
                  defaultMessage="已部署"
                />
              ) : (
                <FormattedMessage
                  id="device_group_list.table.list.undeployed.isEnable"
                  defaultMessage="未部署"
                />
              )}
            </span>
          </div>
        );
      },
    },

    {
      title: <FormattedMessage id="pages.searchTable.titleOption" defaultMessage="操作" />,
      dataIndex: 'option',
      valueType: 'option',
      fixed: 'right',
      key: 'option',
      render: (_, record) => [
        <TableActionCard
          key="TableActionCardRef"
          renderActions={[
            // TODO 设为默认交互补充
            {
              key: 'setModel',
              renderDom: (
                <Button
                  key="setModel"
                  type="link"
                  size="small"
                  onClick={() => {
                    setCurrentRow(record);
                    setIsSettingOpen(true);
                    // history.push('/home/model-detail');
                    // doToDetail(record);
                    // setShowDetail(true);
                  }}
                >
                  <FormattedMessage
                    id="device_group_list.table.list.action.setModel"
                    defaultMessage="基础模型配置"
                  />
                </Button>
              ),
            },
            {
              key: 'updateDetail',
              renderDom: (
                <Button
                  key="update"
                  type="link"
                  size="small"
                  onClick={() => {
                    // TODO 编辑在新增联调后实现
                    // setCurrentRow(record);
                    // history.push('/home/model-detail');
                    // doToDetail(record);
                    // setShowDetail(true);
                    // setUpdateModalOpen(true);
                  }}
                >
                  <FormattedMessage id="pages.searchTable.update" defaultMessage="编辑" />
                </Button>
              ),
            },
            {
              key: 'destroy',
              renderDom: (
                <IsDelete
                  deleteApi={() => {
                    handleDestroy(record).then(() => {});
                  }}
                ></IsDelete>
              ),
            },
          ]}
        ></TableActionCard>,
      ],
    },
  ];

  return (
    <div className="dg_deviceList_wrap">
      <ProTable
        style={{
          display: isSettingOpen ? 'none' : 'block',
        }}
        className="gn_pro_table"
        cardProps={{
          bodyStyle: { padding: 0 },
        }}
        // 标题栏
        toolBarRender={() => [
          <Access
            accessible={access.canUpdate(history.location.pathname)}
            key={`${history.location.pathname}-add`}
          >
            <div className="mb-[16px] ">
              <Button
                className="mr-[12px]"
                type="primary"
                key="add"
                onClick={() => {
                  setCreateModalOpen(true);
                }}
              >
                <FormattedMessage
                  id="device_group_list.table.list.action.new"
                  defaultMessage="新建"
                />
              </Button>
              <Button
                key="deviceType"
                onClick={() => {
                  handleSetDeviceType();
                }}
              >
                <FormattedMessage
                  id="device_group_list.table.list.action.deviceType"
                  defaultMessage="设备分类"
                />
              </Button>
            </div>
          </Access>,
        ]}
        search={false}
        // scroll={{ y: proTableCommonOptions.commscrollY, x: proTableCommonOptions.commscrollX }}
        options={{ fullScreen: false, setting: false, density: false, reload: false }}
        actionRef={actionRef}
        rowKey="id"
        onDataSourceChange={(data) => {
          console.log(data, 'onDataSourceChange_data');
          // let CategoryFkIdIds: any = data.map((v) => {
          //   return v.categoryFkId;
          // });
          // setCategoryFkIdIds(CategoryFkIdIds);
        }}
        pagination={{
          ...proTablePaginationOptions,
          pageSize: currentPageSize,
          onChange: (page, pageSize) => setCurrentPageSize(pageSize),
        }}
        columnsState={{
          persistenceKey: 'algorithm_model_list',
          persistenceType: 'localStorage',
        }}
        request={async (params = {}) => {
          const { current, ...rest } = params;
          const reqParams = {
            page: current,
            ...rest,
          };
          let resp = await getDeviceListByGroup({ ...reqParams });
          console.log(resp, 'getDeviceListByGroup_resp');
          return {
            data: resp.data?.results,
            success: resp.success,
            total: resp.data.count,
            current: current,
            pageSize: currentPageSize,
          };
        }}
        columns={columns}
      />
      {isSettingOpen ? (
        <>
          <InnerPageBack
            backType="custom"
            toBack={() => {
              setIsSettingOpen(false);
            }}
            size={14}
            title="模型列表"
          ></InnerPageBack>
          <ModelSetting info={currentRow}></ModelSetting>
        </>
      ) : (
        <></>
      )}

      <CreateDeviceForm
        createModalOpen={createModalOpen}
        handleModal={handleCreateModal}
        reload={reloadList}
      />
      <CategorizeUpdate
        visible={deviceTypeOpen}
        handleModal={handleSetDeviceType}
        values={{ deviceType: [{ name: '', value: '' }] }}
        apiSource={getDictDeviceType}
        modalFormProps={{
          categorizeFormProps: {
            label: (
              <FormattedMessage
                id="device_group_list.table.list.action.deviceType"
                defaultMessage="设备分类"
              />
            ),
            name: 'deviceType',
          },
          categorizeModelProps: {
            title: intl.formatMessage({
              id: 'device_group_list.table.list.action.setDeviceType',
              defaultMessage: '新建',
            }),
          },
        }}
      />
    </div>
  );
};

export default DeviceList;
