/**
 * @Description: 企业信息页
 * @交互说明
 * 1、展示企业基本信息
 * 2、账号信息展示
 * 3、展示企业算法不分页列表
 * 4、修改企业信息
 */
import { useBusinessInfo } from '@/hooks/useBusinessInfo';

import { useMoment } from '@/hooks/useMoment';
import { getBusinessAlgorithmList, getBusinessDetail } from '@/services/testApi/businessProject';
import { isSuccessApi } from '@/utils/forApi';
import { ProCard, ProList } from '@ant-design/pro-components';
import { Button } from 'antd';

import React, { useEffect, useState } from 'react';
import { proTablePaginationOptions } from '../../../../config/defaultTable';
// import AlarmDetails from './components/AlarmDetails';
import AccountPsw from './components/accountPsw';
import AlgorithmCard from './components/algorithmCard';
import BaseInfo from './components/baseInfo';
import UpdateForm from './components/updateForm';

import './index.less';
import { ReactComponent as YaxinshijueIcon } from '/public/home/yaxinshijue_icon.svg';

// eslint-disable-next-line react-hooks/rules-of-hooks
const { formatTimeByDateType } = useMoment();

const BusinessInfo: React.FC = () => {
  //state
  const [detailInfo, setDetailInfo] = useState<Record<string, any>>({});
  const { getStoreBusinessInfo } = useBusinessInfo();
  const [updateModalOpen, setUpdateModalOpen] = useState<boolean>(false);

  // 未启用
  /**
   * @en-US International configuration
   * @zh-CN 国际化配置
   * */
  // const access = useAccess();
  // const intl = useIntl();
  // const actionRef = useRef<ActionType>();
  //  动态设置每页数量
  const [currentPageSize, setCurrentPageSize] = useState<number>(10);
  const [currentPage, setCurrentPage] = useState<number>(1);
  const [total, setTotal] = useState<number>(0);
  const [list, setList] = useState<any>([]);

  // 更新
  const handleUpdateModal = () => {
    if (updateModalOpen) {
      setUpdateModalOpen(false);
    } else {
      setUpdateModalOpen(true);
    }
  };

  // 处理初始值
  function loadList(dataList: Record<string, any>[]) {
    console.log(dataList, 'loadList');
    let finalList: { content: React.JSX.Element }[] = [];
    if (Array.isArray(dataList) && dataList.length) {
      finalList = dataList.map((info, index) => {
        return {
          content: <AlgorithmCard info={info} key={index}></AlgorithmCard>,
        };
      });
    }
    setList(() => [...finalList]);
  }

  // 初始化加载
  async function loadDetailData() {
    const { id } = getStoreBusinessInfo();
    const resp = await getBusinessDetail({ id });
    if (isSuccessApi(resp)) {
      setDetailInfo(resp?.data);
    }
  }

  // 算法列表
  async function initList(tabId: string) {
    const reqParams = {
      page: currentPage,
      pageSize: currentPageSize,
      // desc: false,
      warning_type: tabId,
      // ...rest,
    };
    const resp = await getBusinessAlgorithmList({ ...reqParams });
    // console.log(resp,'resp');
    // setCurrentPageSize(resp?.data?.count)
    setTotal(resp?.data?.count);
    loadList(resp?.data?.results);
  }

  useEffect(() => {
    initList();
  }, [currentPage, currentPageSize]);

  useEffect(() => {
    loadDetailData();
  }, []);
  return (
    <div className="businessInfo_page pb-[1px]">
      <div className="gn_head_card mb-[20px]">
        <ProCard
          className="gn_card pb-[16px]"
          title={<span className="head3">基础信息</span>}
          extra={
            <Button
              type="primary"
              onClick={() => {
                handleUpdateModal();
              }}
            >
              修改企业信息
            </Button>
          }
        >
          <div className="baseInfo_box">
            <div className="flex pb-[12px]">
              {/* // TODO 替换使用公司的logo字段  */}
              <YaxinshijueIcon></YaxinshijueIcon>
              <div>
                <span className="head3 ">{detailInfo?.name}</span>
                <div className="text_color_2 py-[12px]">
                  注册时间: {formatTimeByDateType(detailInfo?.create_time)}
                </div>
              </div>
            </div>
            <BaseInfo info={detailInfo}></BaseInfo>
          </div>
        </ProCard>
      </div>

      <div className="gn_head_card mb-[20px]">
        <ProCard className="gn_card" title={<span className="head3">账号信息</span>}>
          <AccountPsw></AccountPsw>
        </ProCard>
      </div>

      <div className="gn_head_card mb-[20px]">
        <ProCard
          className="gn_card pb-[16px]"
          title={<span className="head3">企业算法({total})</span>}
        >
          <ProList<any>
            className="gn_pro_list"
            ghost={true}
            itemCardProps={{
              ghost: true,
              bodyStyle: { padding: 0, margin: 0 },
              style: {
                width: '100%',
                border: 0,
              },
            }}
            cardProps={{
              bodyStyle: {
                borderRadius: 8,
              },
            }}
            pagination={{
              ...proTablePaginationOptions,
              total: total,
              current: currentPage,
              pageSize: currentPageSize,
              showSizeChanger: true,
              onChange: (page, pageSize) => {
                console.log(page, pageSize);
                setCurrentPage(page);
                setCurrentPageSize(pageSize);
              },
            }}
            showActions="hover"
            rowSelection={false}
            grid={{ gutter: 16, xs: 1, md: 1, lg: 2, xl: 3, xxl: 4 }}
            metas={{
              type: {
                // 不展示在筛选项
                hideInSearch: true,
              },
              content: {
                hideInSearch: true,
              },
              actions: {
                cardActionProps: 'extra',
              },
            }}
            dataSource={list}
          />
        </ProCard>
        <UpdateForm
          updateModalOpen={updateModalOpen}
          values={detailInfo || {}}
          handleModal={handleUpdateModal}
          reload={loadDetailData}
        />
      </div>
    </div>
  );
};

export default BusinessInfo;
